@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_RUMBLE_EFFECT_H
-#define RETRO_RUMBLE_EFFECT_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
@@ -11,6 +10,10 @@
 
 G_BEGIN_DECLS
 
+#define RETRO_TYPE_RUMBLE_EFFECT (retro_rumble_effect_get_type ())
+
+GType retro_rumble_effect_get_type (void) G_GNUC_CONST;
+
 /**
  * RetroRumbleEffect:
  * @RETRO_RUMBLE_EFFECT_STRONG: the strong rumble effect
@@ -27,5 +30,3 @@ typedef enum
 } RetroRumbleEffect;
 
 G_END_DECLS
-
-#endif /* RETRO_RUMBLE_EFFECT_H */
